// HUD and other client goodies. Unless Persona.
// Or you are using 2.2.9 or lower.

if not WindowsTheComputer then return end
if srb2p then return end

local fader = 0
local mpeg = 3
local winglow = 1
local tokenpresent = false
local location = 0
local sscheck = 0
local mspaint = CV_FindVar("canyon.mid")
local totitle = false	
local tocredits = false
local toend = false
local mapname = "aeiou"
local act = "act"
local docustomintro = true
local actcolor = 0
local shutdown = 0
local coop = false
local dx = CV_FindVar("DirectX")

local function controlpanel()
	S_StartSound(nil, sfx_uihmsn, consoleplayer)
end

local isdebug = CV_FindVar("windbg")

local dxhuddrawalt = CV_RegisterVar({
	name = "dxhudalt",
	defaultvalue = 0,
	PossibleValue = {default=0, alt=1}
})

local cooldown = CV_RegisterVar({
	name = "wintimer",
	defaultvalue = 0,
	flags = CV_SHOWMODIF | CV_CALL,
	PossibleValue = {default=0, detailed=1},
	func = controlpanel
})

// The custom titlecard. 1995 called.
local function customintro(player, arg)
	if arg then
		arg = arg:lower()
		if arg == "0" or arg == "disable" or arg == "false"
			docustomintro = false
			player.wintro = false
			CONS_Printf(player, "Custom title card disabled.")
			S_StartSound(nil, sfx_uihmsn, consoleplayer)
		elseif arg == "1" or arg == "enable" or arg == "true"
			docustomintro = true
			player.wintro = true
			CONS_Printf(player, "Custom title card enabled.")
			S_StartSound(nil, sfx_uihmsn, consoleplayer)
		else
			CONS_Printf(player, "If true, a custom title card will be displayed. Currently\x82\ " + docustomintro + "\x80\.")
		end
	end
end

// Per-player control of aforementioned titlecard.
COM_AddCommand("winintro", function(player, arg)
	if player.wintro == nil then player.wintro = true end
	if arg then customintro(player, arg)
	else
		if netgame then
			CONS_Printf(player, "If true, a custom title card will be displayed. Currently\x82\ " + player.wintro + "\x80\.")
		else
			CONS_Printf(player, "If true, a custom title card will be displayed. Currently\x82\ " + docustomintro + "\x80\.")
		end
	end
end)

COM_AddCommand("dxhud", function(player, arg)
	if player.dxhudalt == nil then player.dxhudalt = false end
	if player.dxhudshift == nil then player.dxhudshift = 0 end
	if arg then
		arg = arg:lower()
		if arg == "default" or arg == "normal" or arg == "0" then
			CV_StealthSet(dxhuddrawalt, 0)
			player.dxhudalt = false
			player.dxhudshift = 0
			CONS_Printf(player, "Windows-related HUD had been returned to default.")
			S_StartSound(nil, sfx_uihmsn, consoleplayer)
		elseif arg == "alt" or arg == "alternate" or arg == "alternative" or arg == "1" then
			CV_StealthSet(dxhuddrawalt, 1)
			player.dxhudalt = true
			player.dxhudshift = 16
			CONS_Printf(player, "Windows-related HUD had been moved.")
			S_StartSound(nil, sfx_uihmsn, consoleplayer)
		else
			CONS_Printf(p, "Invalid or unknown argument.")
		end
	else
		CONS_Printf(player, "Shifts the Windows-related HUD cooldowns up if enabled.")
		CONS_Printf(player, "Useful if you're using custom HUDs already (like \x82\MRCE\x80\).")
	end
end)

// Randomize which sound to use.
addHook("ThinkFrame", function()
	if leveltime%TICRATE then
		shutdown = P_RandomKey(5)
	end
end)

// Shutting down...
addHook("GameQuit", function()
	if shutdown == 0 then
		S_StartSound(nil, sfx_512600)
	elseif shutdown == 1 then
		S_StartSound(nil, sfx_502195)
	elseif shutdown == 2 then
		S_StartSound(nil, sfx_501946)
	elseif shutdown == 3 then
		S_StartSound(nil, sfx_irbgin)
	elseif shutdown == 4 then
		S_StartSound(nil, sfx_606000)
	end
end)

// Map shenanigans for titlecard and intermission.
addHook("MapLoad", function(gamemap)
	location = mapheaderinfo[gamemap].nextlevel
	mapname = mapheaderinfo[gamemap].lvlttl
	act = mapheaderinfo[gamemap].actnum
	if mapheaderinfo[gamemap].bonustype == 2 or mapheaderinfo[gamemap].bonustype == 1 then actcolor = 20480
	else actcolor = 0 end
	if location == 1100 then totitle = true else totitle = false end
	if location == 1102 then tocredits = true else tocredits = false end
	if location == 1103 then toend = true else toend = false end
	if (G_IsSpecialStage(gamemap)) then
		sscheck = true
		actcolor = 8192
	else
		sscheck = false
	end
end)

addHook("PlayerThink", function(player)
	if player.mo and player.mo.valid and player.mo.skin == "windows" then
		player.iswindows = true
	else
		player.iswindows = false
	end
	if G_PlatformGametype() then coop = true else coop = false end
	if player.dxhudalt != dxhuddrawalt.value then player.dxhudalt = dxhuddrawalt.value end
	if player.dxhudalt and player.dxhudshift == 0 then player.dxhudshift = 16
	elseif not player.dxhudalt and player.dxhudshift == 16 then player.dxhudshift = 0 end
end)

addHook("MusicChange", function(oldname, newname)
	if newname == "_creds" and mspaint.value != 0 and consoleplayer and consoleplayer.iswindows then
		return "XPOOBE"
	end
end)

// The World Wide Web at your fingertips.
local function WinTitle(v)
	v.draw(4, 4, v.cachePatch("WINRUN"), V_SNAPTOTOP|V_SNAPTOLEFT|V_MEDSCALEPATCH|V_HUDTRANSHALF)
	if (OLDC and OLDC.Data and CURRENT_YEAR and CURRENT_ROUND) then
		v.drawString(24, 8, ("Windows & OLDC " + CURRENT_YEAR + " Round " + CURRENT_ROUND + " initialized."), V_SNAPTOTOP|V_SNAPTOLEFT|V_SKYMAP|V_MEDSCALEPATCH|V_HUDTRANSHALF, "thin")
	else
		v.drawString(24, 8, ("Windows initialized."), V_SNAPTOTOP|V_SNAPTOLEFT|V_SKYMAP|V_MEDSCALEPATCH|V_HUDTRANSHALF, "thin")
	end
	shutdown = v.RandomKey(5)
end

// Actual HUD shenanigans.
local function WinHUD(v, player, camera)
	if player.mo and player.mo.valid and player.mo.skin == "windows" then
		if player.winpopup != nil and player.xpcooldown != nil then
			local winready = v.cachePatch("WINREADY")
			local winwarn = v.cachePatch("WINWARN")
			local kgrow = v.cachePatch("KGROW")
			local winnotready = v.cachePatch("WINNOT")
			local directx = v.cachePatch("WINDX")
			local directxbw = v.cachePatch("WINDX1")
			local spiking = v.cachePatch("WINBUST")
			local startbtn = v.cachePatch("WINSTART")
			local growth = CV_FindVar("kartgrow")
			local directxtoggle = CV_FindVar("DirectX")
			local kflash = leveltime%2
			local fadetime = leveltime%4
			local run = (10*TICRATE - player.winpopup)
			local clocking = (60*TICRATE - player.xpcooldown)
			local growthtimer = player.powers[pw_sneakers]
			local directplay = player.cpanel
			if isdebug.value or not WindowsTheComputer.versionpublic then
				v.drawString(304, 16, WindowsTheComputer.versiontext1,V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSHALF|V_SKYMAP, "thin-right")
				v.drawString(304, 24, WindowsTheComputer.versiontext2,V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSHALF|V_SKYMAP, "thin-right")
			end
			if player.powers[pw_super] != 0 and (player.hyper == nil or player.hyper.capable == false) then
				if not player.xpready then
					v.draw(17, 141-player.dxhudshift, winnotready, V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
					if not cooldown.value then
						v.drawString(37, 145-player.dxhudshift, G_TicsToSeconds(clocking), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GRAYMAP, "thin")
					else
						v.drawString(37, 145-player.dxhudshift, G_TicsToSeconds(clocking) + "." + G_TicsToCentiseconds(clocking), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GRAYMAP, "thin")
					end
				elseif player.xpready then
					v.draw(17, 141-player.dxhudshift, winready, V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
					v.drawString(37, 145-player.dxhudshift, ("Ready"), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GREENMAP, "thin")
				end
			elseif player.powers[pw_super] != 0 and (player.hyper and player.hyper.capable == true) then
				if player.canxpblast then
					if not player.xpready then
						v.draw(17, 141-player.dxhudshift, winnotready, V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
						if not cooldown.value then
							v.drawString(37, 145-player.dxhudshift, G_TicsToSeconds(clocking), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GRAYMAP, "thin")
						else
							v.drawString(37, 145-player.dxhudshift, G_TicsToSeconds(clocking) + "." + G_TicsToCentiseconds(clocking), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GRAYMAP, "thin")
						end
					elseif player.xpready then
						if player.hyper and player.hyper.capable == true then
							v.draw(17, 141-player.dxhudshift, winwarn, V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
							v.drawString(37, 145-player.dxhudshift, ("Ready"), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_YELLOWMAP, "thin")
						end
					end
				else
					v.draw(17, 141-player.dxhudshift, winnotready, V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
					v.drawString(37, 145-player.dxhudshift, "OFF", V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_REDMAP, "thin")
				end
			end
			if growth.value == 1 and player.powers[pw_sneakers] != 0 then
				if kflash == 1 then
					v.draw(292, 10, kgrow, V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANS)
				end
				if player.powers[pw_sneakers] >= 3*TICRATE then
					if not cooldown.value then
						if player.powers[pw_sneakers] > 60*TICRATE then
							v.drawString(300, 16, G_TicsToMinutes(growthtimer, true) + ":" + G_TicsToSeconds(growthtimer), V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSDOUBLE|V_BLUEMAP, "center")
						else
							v.drawString(300, 16, G_TicsToSeconds(growthtimer), V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSDOUBLE|V_BLUEMAP, "center")
						end
					else
						if player.powers[pw_sneakers] > 60*TICRATE then
							v.drawString(300, 16, G_TicsToMinutes(growthtimer, true) + ":" + G_TicsToSeconds(growthtimer) + "." + G_TicsToCentiseconds(growthtimer), V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSDOUBLE|V_BLUEMAP, "center")
						else
							v.drawString(300, 16, G_TicsToSeconds(growthtimer) + "." + G_TicsToCentiseconds(growthtimer), V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSDOUBLE|V_BLUEMAP, "center")
						end
						// v.drawString(300, 16, G_TicsToMinutes(growthtimer, true) + ":" + G_TicsToSeconds(growthtimer) + "." + G_TicsToCentiseconds(growthtimer), V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSDOUBLE|V_BLUEMAP, "center")
					end
				elseif player.powers[pw_sneakers] < 3*TICRATE then
					if kflash == 1 then 
						if not cooldown.value then
							v.drawString(300, 16, G_TicsToSeconds(growthtimer), V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSDOUBLE|V_BLUEMAP, "center")
						else
							v.drawString(300, 16, G_TicsToSeconds(growthtimer) + "." + G_TicsToCentiseconds(growthtimer), V_SNAPTOTOP|V_SNAPTORIGHT|V_PERPLAYER|V_HUDTRANSDOUBLE|V_BLUEMAP, "center")
						end
					end
				end
			end
			if directxtoggle.value == 1 then
				if player.dxready then
					v.draw(16, 158-player.dxhudshift, directx, V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
					if directplay > 0 then
						if not cooldown.value then
							v.drawString(37, 162-player.dxhudshift, "Ready / " + G_TicsToSeconds(directplay), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_YELLOWMAP, "thin")
						else
							v.drawString(37, 162-player.dxhudshift, "Ready / " + G_TicsToSeconds(directplay) + "." + G_TicsToCentiseconds(directplay), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_YELLOWMAP, "thin")
						end
					else
						v.drawString(37, 162-player.dxhudshift, "Ready", V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_YELLOWMAP, "thin")
					end
				else
					v.draw(16, 158-player.dxhudshift, directxbw, V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
					if directplay > 0 then	
						if not cooldown.value then
							v.drawString(37, 162-player.dxhudshift, G_TicsToSeconds(run) + " / " + G_TicsToSeconds(directplay), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GRAYMAP, "thin")
						else
							v.drawString(37, 162-player.dxhudshift, G_TicsToSeconds(run) + "." + G_TicsToCentiseconds(run) + " / " + G_TicsToSeconds(directplay) + "." + G_TicsToCentiseconds(directplay), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GRAYMAP, "thin")
						end
					else
						if not cooldown.value then
							v.drawString(37, 162-player.dxhudshift, G_TicsToSeconds(run), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GRAYMAP, "thin")
						else
							v.drawString(37, 162-player.dxhudshift, G_TicsToSeconds(run) + "." + G_TicsToCentiseconds(run), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_GRAYMAP, "thin")
						end
					end
				end
			end
			if player.exiting == 0 then
				if (player.powers[pw_super] != 0 or (player.solchar and player.solchar.istransformed and player.solchar.istransformed > 1))
				or player.powers[pw_invulnerability] != 0 or player.cpanel > 0 or (FixedDiv(player.speed, player.mo.scale) > 16*FRACUNIT and player.pflags & (PF_SPINNING))
				or FixedDiv(player.speed, player.mo.scale) > 48*FRACUNIT then
					if player.dashmode >= 3*TICRATE and (player.charflags & SF_DASHMODE) and leveltime%4 == 1 then
						v.draw(16, 125-player.dxhudshift, v.cachePatch("WINBUSTDM"), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
					else
						v.draw(16, 125-player.dxhudshift, spiking, V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS)
					end
				end
				fader = 0
			elseif player.exiting >= 1 then
				if not (sscheck) then
					if (fadetime == 1 and fader < 31) then fader = $ + 1 end
					v.fadeScreen(65280, fader) // Do the actual fading.
					if fader == 31 then v.drawFill() end
				end
				if token > 0 and not All7Emeralds(emeralds) then tokenpresent = true  else tokenpresent = false end
			end
		end
	end
	if isdebug.value == 1 and not (player.dxready == nil and player.winpopup == nil and player.cpanel == nil) then
		local hudflag = V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_PERPLAYER|V_HUDTRANS|V_AZUREMAP
		v.drawString(16, 52, ("player.dxready = " + player.dxready), hudflag, "thin")
		v.drawString(16, 60, ("player.winpopup = " + player.winpopup), hudflag, "thin")
		v.drawString(16, 68, ("player.cpanel = " + player.cpanel), hudflag, "thin")
		v.drawString(16, 76, ("player.oldbie = " + player.oldbie), hudflag, "thin")
		v.drawString(16, 84, ("player.newbie = " + player.newbie), hudflag, "thin")
		v.drawString(16, 92, ("player.ohbig = " + player.ohbig), hudflag, "thin")
		v.drawString(16, 100, ("player.cpucooler = " + player.cpucooler), hudflag, "thin")
		v.drawString(16, 108, ("player.defragment = " + player.defragment), hudflag, "thin")
		v.drawString(16, 116, ("player.formnet = " + player.formnet), hudflag, "thin")
	end
end

// Intermission stuff. If not Windows, abort!
local function WinInter(v)
	if not consoleplayer.iswindows then return end
	local bar = v.cachePatch("WINBAR")
	local flash1 = v.cachePatch("WINBAR1")
	local flash2 = v.cachePatch("WINBAR2")
	local flash3 = v.cachePatch("WINBAR3")
	local flash4 = v.cachePatch("WINBAR4")
	local flash5 = v.cachePatch("WINBAR5")
	local flash6 = v.cachePatch("WINBAR6")
	local flash7 = v.cachePatch("WINBAR7")
	local winbg1 = v.cachePatch("WINCLR1")
	local winbg2 = v.cachePatch("WINCLR2")
	local win95init = {flash1, flash2, flash3, flash4, flash5, flash6, flash7, flash6, flash5, flash4, flash3, flash2, flash1}
	v.drawFill() // Black like the command prompt.
	if mpeg > 0 then mpeg = $ - 1
	else
		mpeg = 3
		if winglow < 14 then
			winglow = $ + 1
		end
	end
	if coop then
		v.draw(0, 0, winbg1, V_SNAPTOTOP|V_SNAPTOLEFT)
		if tokenpresent then // If we have tokens, but not all emeralds...
			v.drawString(38, 185, ("Getting ready for a special stage..."), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_REDMAP, "thin")
		elseif location == 1101 then // If we're going to the evaluation screen...
			v.drawString(38, 185, ("Logging results..."), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_REDMAP, "thin")
		elseif toend then // Ending sequence.
			v.drawString(38, 185, ("Completed. Ending the session..."), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_REDMAP, "thin")
		elseif tocredits then // Straight to credits?
			v.drawString(38, 185, ("Initiating credits..."), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_REDMAP, "thin")
		elseif totitle then // From a secret level, probably.
			v.drawString(38, 185, ("Returning to title screen shortly..."), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_REDMAP, "thin")
		elseif location == 25 then // About to race Metal Sonic.
			v.drawString(38, 185, ("Getting ready..."), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_REDMAP, "thin")
		else // Else, fallback...
			v.drawString(38, 185, ("Getting ready for the next act..."), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_REDMAP, "thin")
		end
	else
		// Sounds like we're in a PvE/PvP gamemode.
		v.draw(0, 0, winbg2, V_SNAPTOTOP|V_SNAPTOLEFT)
		v.drawString(38, 185, ("Waiting for next round or match..."), V_SNAPTOBOTTOM|V_SNAPTOLEFT|V_REDMAP, "thin")
	end
	v.draw(0, 177, bar, V_SNAPTOBOTTOM|V_SNAPTOLEFT)
	// Ooo, shiny.
	if winglow > 1 and winglow < 14 then
		v.draw(0, 177, win95init[winglow], V_SNAPTOBOTTOM|V_SNAPTOLEFT)
	else
		winglow = 1
	end
end

// Custom intro.
local function WinLoad(v, player, ticker, endtime)
	if consoleplayer.mo and consoleplayer.mo.valid then
		local wininit = true
		// If this is a netgame, we check against a player variable. Otherwise, a local variable instead.
		if consoleplayer.mo.skin == "windows" and ((netgame and consoleplayer.wintro) or (docustomintro and not netgame)) then
			if wininit then
				hud.disable("stagetitle")
				local window = v.cachePatch("WINLOAD")
				if ticker < endtime - TICRATE then
					v.draw(44, 73, window, V_SNAPTOTOP|V_PERPLAYER)
					if act != 0 then
						v.drawString(160, 148, mapname + " act " + act, V_SNAPTOTOP|V_PERPLAYER + actcolor, "center")
					else
						v.drawString(160, 148, mapname, V_SNAPTOTOP|V_PERPLAYER + actcolor, "center")
					end
				end
			end
		else
		// If not Windows... let's try to not override the (custom) HUD too much.
			if wininit then
				if not hud.enabled("stagetitle") then hud.enable("stagetitle") end
				wininit = false
			end
		end
	end
end

hud.add(WinTitle, "title")
hud.add(WinHUD, "game")
hud.add(WinLoad, "titlecard")
hud.add(WinInter, "intermission")

local path = WindowsTheComputer
// winver.exe intensifies.
COM_AddCommand("winver", function(player, unused)
	CONS_Printf(player, "\x8A\Windows The Computer")
	CONS_Printf(player, "Version\x8A\ " + path.versionmajor + "." + path.versionminor + "\x80\ on SRB2\x82\ " + VERSIONSTRING)
	if isdedicatedserver then
		print("Running in dedicated server mode.")
		return
	end
	if devparm then CONS_Printf(player, "Running with debug mode.") end
	if player.iswindows or (player and player.valid and player.mo and player.mo.valid and player.mo.skin == "windows") then
		CONS_Printf(player, "Reading configuration information for this player...")
		if player.ftdefbind != nil then
			if player.ftdefbind then
				CONS_Printf(player, "Current \x82\File Toss\x80\ bind is Ring Toss.")
			elseif not player.ftdefbind then
				CONS_Printf(player, "Current \x82\File Toss\x80\ bind is Spin.")
			else
				CONS_Printf(player, "Unknown configuration for \x82\File Toss\x80\, falling back to default.")
				player.ftdefbind = true
			end
		else
			CONS_Printf(player, "Unknown configuration for \x82\File Toss\x80\, falling back to default.")
			player.ftdefbind = true
		end
		if (netgame and player.wintro) or (docustomintro and not netgame) then
			CONS_Printf(player, "Custom title card is enabled.")
		elseif player.wintro == nil or docustomintro == nil then
			CONS_Printf(player, "Unknown configuration for custom title card, falling back to default.")
			if player.wintro == nil then player.wintro = true end
			if docustomintro == nil then docustomintro = true end
		else
			CONS_Printf(player, "Custom title card is disabled.")
		end
		if dx.value == 1 then CONS_Printf(player, "\x82\DirectX Boost\x80\ is enabled.")
		elseif dx.value == 0 then CONS_Printf(player, "\x82\DirectX Boost\x80\ is disabled.")
		else CONS_Printf(player, "Unknown configuration of \x82\DirectX Boost\x80\, returned " + dx.value) end
	end
end)